from openstack.connection import Connection
from openstack.identity.v3.service import Service


def get_usage(connection: Connection, resource_provider_id: str):

    placement_endpoint = connection.endpoint_for(
        service_type="placement", interface="public"
    )

    url = f"{placement_endpoint}/resource_providers/{resource_provider_id}/usages"

    response = connection.session.get(url)

    data = response.json()

    return data["usages"]



from typing import Optional

from pydantic import BaseModel, ConfigDict, ValidationError


class Router(BaseModel):
    model_config = ConfigDict(strict=True)

    router_id: str

    name: Optional[str]

    external_net_id: Optional[str]
    external_net_ip: Optional[str]

    status: str
    project_id: Optional[str]

    created_at: str
    updated_at: str
